////////////////////////////////////////////////////
////////////////////////////////////////////////////
data {
  int<lower=0>  N;          // sample size
  vector[N]     y;          // read skill
  vector[N]     x1;         // online
  vector[N]     x2;         // attitude
  // 1. number of schools as variable Ns (same type as sample size)
  // 2. define cluster variable as integer with lower bound 0 and length N

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
parameters {
  real           b0;      //intercept
  vector[5]      b1;      //reg coeff 
  real<lower=0>  sigmay;  // residual SD y with lower bound zero

  //additional parameters for the mlm
  // 3. u0 is ``latent variable'' (vector with length Ns) 
  // 4. SD of random intercept
  
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
transformed parameters {  
  vector[N]   muy;  // E[y|x]

  // 5. you need to extend this formula with a random intercept u0
  for (i in 1:N){
    muy[i] = b0
            +b1[1]*x1[i]
            +b1[2]*x2[i]
            +b1[3]*x1[i]*x2[i]  //on x att
            +b1[4]*x1[i]*x1[i]  //on^2
            +b1[5]*x2[i]*x2[i]  //att^2
            ;
   }
   
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
model {

  ///////////////////////////////////////////////
  // variables
  ///////////////////////////////////////////////
  y  ~ normal(muy,sigmay);
  // 6. distribution of u0

  ///////////////////////////////////////////////
  // priors
  ///////////////////////////////////////////////
  // regression coefficients
  b0 ~ normal(0,1);
  b1 ~ normal(0,1);

  //SDs
  sigmay ~ cauchy(0,2.5);
  // 7. distribution of SD of u0

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
//generated quantities{
//}

