data {
  int<lower=0> N;          // number of students (level1)
  int<lower=0> Ns;         // number of schools (level2)
  matrix[N,3]  y;          // reading skills
  matrix[N,3]  x1;         // online
  int<lower=0> school[N]; // schoolid
}
parameters {
  real         b0;         // intercept structural model
  vector[3]    b1;         // fixed effects L1 structural model
  vector[2]    ly;         // factor loadings y
  vector[2]    lx1;         // factor loadings x1

  vector<lower=0>[3] sigmay;  // residual SD L1 for y
  vector<lower=0>[3] sigmax1;  // residual SD L1 for x1
  real<lower=0>      sigmaxi; // SD L1 xi
  real<lower=0>      sigmaeta;// residual SD L1 eta
  real<lower=0>      sigmau0;  // residual SD L2

  vector[N]   eta;   // latent dv L1
  vector[N]   xi;    // latent predictor L1
  vector[Ns]  u0;     // random effects
}

transformed parameters {
  matrix[N,3]  muy;  // E[y|eta]
  matrix[N,3]  mux1; // E[x1|xi]
  vector[N]    mueta;// E[eta|xi]

  for (i in 1:N){
    ///////////////////////////////////////////////
    // measurement models
    ///////////////////////////////////////////////
    muy[i,1] =       eta[i];
    muy[i,2] = ly[1]*eta[i];
    muy[i,3] = ly[2]*eta[i];
  
    mux1[i,1] =       xi[i];
    mux1[i,2] = lx1[1]*xi[i];
    mux1[i,3] = lx1[2]*xi[i];
  
    ///////////////////////////////////////////////
    // structural model
    ///////////////////////////////////////////////
    mueta[i] = b0 + 
               b1[1]*xi[i] +             //linear effect of on
               b1[2]*xi[i]*xi[i] +       //quadratic effect of on
               b1[3]*xi[i]*xi[i]*xi[i] + //cubic effect of on
               u0[school[i]];
  
  }
  
  
  
}

model {
  ///////////////////////////////////
  // distribution of y,x
  ///////////////////////////////////
  for(j in 1:3){
    y[,j]  ~ normal(muy[,j],sigmay[j]);
    x1[,j] ~ normal(mux1[,j],sigmax1[j]);
  }

  ///////////////////////////////////
  // distribution of latent variables L1
  ///////////////////////////////////
  eta ~ normal(mueta,sigmaeta);
  xi  ~ normal(0,sigmaxi);

  ///////////////////////////////////
  // distribution of random effects
  ///////////////////////////////////
  u0 ~ normal(0,sigmau0);
  
  ///////////////////////////////////
  // priors measurement model
  ///////////////////////////////////
  ly  ~ normal(0,1);
  lx1 ~ normal(0,1);
  
  sigmay  ~ cauchy(0,2.5);
  sigmax1 ~ cauchy(0,2.5);
  
  ///////////////////////////////////
  // priors structural model
  ///////////////////////////////////
  // fixed effects
  b0 ~ normal(0,1);
  b1 ~ normal(0,1);
  
  // variances and covariances
  sigmaeta ~ cauchy(0,2.5);
  sigmaxi  ~ cauchy(0,2.5);
  sigmau0  ~ cauchy(0,2.5);
  
}

//generated quantities{
//}




