////////////////////////////////////////////////////
////////////////////////////////////////////////////
data {
  int<lower=0> N;
  vector[N]    y;  //read
  vector[N]    x1; //online
  vector[N]    x2; //attitude

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
parameters {
  real           b0; //intercept
  vector[5]      b1; //reg coeff 
  real<lower=0>  sigmay; // residual variance y with lower bound zero
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
transformed parameters {
  vector[N]   muy;  // E[y|x]
  
  for (i in 1:N){
    muy[i] = b0
            +b1[1]*x1[i]
            +b1[2]*x2[i]
            +b1[3]*x1[i]*x2[i]  //on x att
            +b1[4]*x1[i]*x1[i]  //on^2
            +b1[5]*x2[i]*x2[i]; //att^2
   }

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
model {

  ///////////////////////////////////////////////
  // variables
  ///////////////////////////////////////////////
  y ~ normal(muy,sigmay);
  
  ///////////////////////////////////////////////
  // priors
  ///////////////////////////////////////////////
  // regression coefficients
  b0 ~ normal(0,1);
  b1 ~ normal(0,1);

  //SDs
  sigmay ~ cauchy(0,2.5);
  
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
//generated quantities{
//}

