////////////////////////////////////////////////////
////////////////////////////////////////////////////
data {
  int<lower=0> N; // sample size
  matrix[N,4]  x; // indicators of latent predictors
  matrix[N,2]  y; // indicators of latent dv
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
parameters {
  real      b0;                //intercept eta
  vector[3] b1;                //regression coeff 

  vector<lower=0>[4] sigmax;   // residual SD indicators
  vector<lower=0>[2] sigmay;   // residual SD indicators
  real<lower=0>      sigmaeta; // residual SD eta
  vector<lower=0>[2] sigmaxi;  // SD's xi
  corr_matrix[2]     rhoxi;      // correlation matrix xi
  
  vector[N]   eta;             // latent vars
  matrix[N,2] xi;

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
transformed parameters {
  matrix[N,4] mux;     // E[x|xi]
  matrix[N,2] muy;     // E[y|eta]
  vector[N]   mueta;   // E[eta|xi]
  matrix[2,2] phixi;     // Cov(xi)
  vector[2]   muxi;    // E(xi)
  
  // zero means: Alternatively muxi can be a parameter (see below)
  // Due to the centering of the data, we do not need a mean
  muxi[1] = 0;
  muxi[2] = 0;
  // covariance matrix
  phixi = quad_form_diag(rhoxi,sigmaxi);
  // quad_form_diag multiplies a correlation matrix 
  // with a vector of SD's to create a covariance matrix
  
  for (i in 1:N){
    ///////////////////////////////////////////////
    // measurement model: all lambdas are 1
    ///////////////////////////////////////////////
    mux[i,1] = xi[i,1];
    mux[i,2] = xi[i,1];
    
    mux[i,3] = xi[i,2];
    mux[i,4] = xi[i,2];

    muy[i,1] = eta[i];
    muy[i,2] = eta[i];
    
    ///////////////////////////////////////////////
    // structural model
    ///////////////////////////////////////////////
    mueta[i] = b0
              +b1[1]*xi[i,1]
              +b1[2]*xi[i,2]
              +b1[3]*xi[i,1]*xi[i,2];
   }

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
model {

  ///////////////////////////////////////////////
  // manifest variables
  ///////////////////////////////////////////////
  for(k in 1:4){x[,k] ~ normal(mux[,k],sigmax[k]);}
  for(k in 1:2){y[,k] ~ normal(muy[,k],sigmay[k]);}
  
  ///////////////////////////////////////////////
  // latent variables
  ///////////////////////////////////////////////
  eta ~ normal(mueta,sigmaeta);
  
  for(i in 1:N){
    xi[i,] ~ multi_normal(muxi,phixi);
  }
   
  
  ///////////////////////////////////////////////
  // priors
  ///////////////////////////////////////////////
  // regression coefficients
  b0 ~ normal(0,1);
  b1 ~ normal(0,1);

  // means
  //muxi ~ normal(0,1);
  
  // SDs
  sigmax   ~ cauchy(0,2.5);
  sigmay   ~ cauchy(0,2.5);
  sigmaeta ~ cauchy(0,2.5);
  sigmaxi  ~ cauchy(0,2.5);
  
  // correlation matrix
  rhoxi ~ lkj_corr(2);
  
  

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
//generated quantities{
//}

