////////////////////////////////////////////////////
////////////////////////////////////////////////////
data {
  int<lower=0>  N;          // sample size
  int<lower=0>  Ns;         // number of schools
  vector[N]     y;          // read skill
  vector[N]     x1;         // online
  vector[N]     x2;         // attitude
  int<lower=0>  school[N];  // cluster variable
  
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
parameters {
  real           b0;      //intercept
  vector[5]      b1;      //reg coeff 
  real<lower=0>  sigmay;  // residual SD y with lower bound zero

  //additional parameters for the mlm
  // ``latent variable'' == intercept
  vector[Ns]     u0;
  // SD of random intercept
  real<lower=0>  sigmau0;

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
transformed parameters {  
  vector[N]   muy;  // E[y|x]

  for (i in 1:N){
    muy[i] = b0
            +b1[1]*x1[i]
            +b1[2]*x2[i]
            +b1[3]*x1[i]*x2[i]  //on x att
            +b1[4]*x1[i]*x1[i]  //on^2
            +b1[5]*x2[i]*x2[i]  //att^2
            +u0[school[i]];
   }
   
   // Note: u0[school[i]] selects the random term for 
   // for each student i...N in his/her school

}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
model {

  ///////////////////////////////////////////////
  // variables
  ///////////////////////////////////////////////
  y  ~ normal(muy,sigmay);
  u0 ~ normal(0,sigmau0);
  
  ///////////////////////////////////////////////
  // priors
  ///////////////////////////////////////////////
  // regression coefficients
  b0 ~ normal(0,1);
  b1 ~ normal(0,1);

  //SDs
  sigmay ~ cauchy(0,2.5);
  sigmau0 ~ cauchy(0,2.5);
  
}

////////////////////////////////////////////////////
////////////////////////////////////////////////////
//generated quantities{
//}

